function [Tension_tan_new, m_tot_2, m_em_2, m_sup_new, D_ag_new,...
    l_lam_new, cost_Cu, cost_Feys, cost_Feyr, cost_PM, cost_str] =...
    scaling(P_rated_new, ref, handles)

global BDet ADet SDet k_Cu k_Feys k_Feyr k_PM;

%Array of Reference Machine structs
Det=[BDet,ADet,SDet];

%Reference Machine Parameters

P_rated = Det(ref).Value(1);      %MW*
P_shaft = Det(ref).Value(2);      %MW
D_ag = Det(ref).Value(3);         %mm*
r_ag = D_ag/2;
delta_ag = Det(ref).Value(4);     %mm*
l_rotor = Det(ref).Value(5);      %mm
m_tot_1 = Det(ref).Value(6);        %ton* 
n_rated = Det(ref).Value(7);      %RPM*
l_external =Det(ref).Value(8);    %mm*
D_ext = Det(ref).Value(9);      %mm
r_ext = D_ext/2;
T_out = Det(ref).Value(10);       %kNm*
T_in = 1.05*T_out;                %kNm
l_lam = Det(ref).Value(12);   %mm
V_r_1=pi/4*D_ag^2*l_lam*10^-9; %m^3
D_mag_out =Det(ref).Value(13);  %mm
Tension_tan = T_in/(D_ag/1000/2)/...
    ((l_lam/1000)*(pi*D_ag/1000));     %kN/m^2*
%ref1 has external rotor
if ref==1
    Tension_tan = T_in/(D_mag_out/1000/2)/...
    ((l_lam/1000)*(pi*D_mag_out/1000));     %kN/m^2*
end
%n_rated was decided to be kept constant
n_rated_new=n_rated;

%Machine Constant
C_mec = P_rated/((D_ag/1000)^2*(l_lam/1000)*n_rated);

%ratios Blaaster101
x_ext = D_ext/D_ag;
x_mag = D_mag_out/D_ag;

%new values
AR = l_lam/D_ag; %aspect ratio
D_ag_new=(P_rated_new/(C_mec*AR*n_rated_new))^(1/3);
l_lam_new=(AR^2*P_rated_new/(C_mec*n_rated_new))^(1/3);
D_ext_new=x_ext*D_ag_new;
D_mag_out_new=x_mag*D_ag_new;


% ---TORQUE AND TENSION
% T_in_new = T_in*(r_ag_new/r_ag)^3 %(Reichert)
T_in_new = 1.05*P_rated_new*1000/(n_rated_new*(pi/30)); %[kNm],
%multiplying with 1.05 to compensate for losses in generator

Tension_tan_new = Tension_tan;
%T_in_new/(D_mag_out_new/2)/...
%    ((l_lam_new)*(pi*D_mag_out_new));   %[kN/m^2]

% ---TOTAL MASS
% % For Blaaster as reference: Modified scaling
% k_a_B = 0.529; %Active mass ratio, m_active/m_total,
% %for Blaaster101 generator, source: Blaaster Wind Technology
% k_a_g = 0.2; %Active mass ratio for ScanWind and ABB generators,
% %source: Zhang
% if ref == 1
%     m_tot_new = 69.4*P_rated_new/sqrt(n_rated_new); %[ton]
%     m_act_new = k_a_B*m_tot_new; %(Modified Zhang)
% else
%     m_tot_new = 97.7*P_rated_new/sqrt(n_rated_new); %[ton]
%     m_act_new = k_a_g*m_tot_new; %[ton], (Zhang)
% end

[m_em_2,m_cy2,m_beam2,m_tot_2]=mass_scale(m_tot_1,P_rated,P_rated_new);

% ---SUPPORTING MASS
m_sup_new = m_cy2+m_beam2; %[ton]


% ---COST ESTIMATE
%Cost Parameters, Source: Zhang
c_Cu=str2double(get(handles.edit_c_cu, 'string')); %EUR/kg
c_Fe=str2double(get(handles.edit_c_fe, 'string')); %EUR/kg
c_PM=str2double(get(handles.edit_c_pm, 'string')); %EUR/kg

%Cost of Active Materials
cost_Cu = c_Cu*k_Cu*m_em_2/1000;      %MEUR
cost_Feys = c_Fe*k_Feys*m_em_2/1000;  %MEUR
cost_Feyr = c_Fe*k_Feyr*m_em_2/1000;  %MEUR
cost_PM = c_PM*k_PM*m_em_2/1000;      %MEUR

%Cost of Supporting Materials
cost_str=c_Fe*(m_sup_new)/1000;       %MEUR
